@@ -77,6 +77,16 @@ void k9call::setupUi() {
 	
 	ui.name->setStyleSheet(m_StyleLetters);
 	ui.next->setStyleSheet(m_StyleLetters);
+	ui.call->setStyleSheet(m_StyleCallButton);
+	ui.clear->setStyleSheet(m_StyleClearButton);
+
+	// Setup pic
+	ui.pic->setScene(new QGraphicsScene());
+
+	// Make the background TRANSPARENT!
+	
+	setStyleSheet("background: rgba(0,0,0,128)");
+	// setAttribute(Qt::WA_TranslucentBackground);
 }
 
 void k9call::setupButton(KeypadButton idx, QPushButton* button) {
@@ -89,7 +99,6 @@ void k9call::createStyle()
 {
 	m_StyleLetters =
 	        "QPushButton {"
-	        "	margin: 0 1px 0 1px;"
 	        "	color: white;"
 	        "	background-color: qlineargradient(x1: 0, y1: 0, "
 	                                             "x2: 0, y2: 1, "
@@ -101,7 +110,48 @@ void k9call::createStyle()
 	        "	border-color: #000;"
 	        "}"
 	        "QPushButton:pressed {"
-	        "	background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #0d5ca6, stop: 1 #2198c0);"
+	        "	background-color: qlineargradient(x1: 0, y1: 0, "
+	                                             "x2: 0, y2: 1, "
+	                                             "stop: 0 #16B, "
+	                                             "stop: 1 #2AC);"
+	        "}";
+
+	m_StyleCallButton =
+	        "QPushButton {"
+	        "	color: white;"
+	        "	background-color: qlineargradient(x1: 0, y1: 0, "
+	                                             "x2: 0, y2: 1, "
+	                                             "stop: 0 #242, "
+	                                             "stop: 1 #353);"
+	        "	border-style: outset;"
+	        "	border-radius: 3px;"
+	        "	border-width: 1px;"
+	        "	border-color: #020;"
+	        "}"
+	        "QPushButton:pressed {"
+	        "	background-color: qlineargradient(x1: 0, y1: 0, "
+	                                             "x2: 0, y2: 1, "
+	                                             "stop: 0 #393, "
+	                                             "stop: 1 #282);"
+	        "}";
+
+	m_StyleClearButton =
+	        "QPushButton {"
+	        "	color: white;"
+	        "	background-color: qlineargradient(x1: 0, y1: 0, "
+	                                             "x2: 0, y2: 1, "
+	                                             "stop: 0 #422, "
+	                                             "stop: 1 #533);"
+	        "	border-style: outset;"
+	        "	border-radius: 3px;"
+	        "	border-width: 1px;"
+	        "	border-color: #200;"
+	        "}"
+	        "QPushButton:pressed {"
+	        "	background-color: qlineargradient(x1: 0, y1: 0, "
+	                                             "x2: 0, y2: 1, "
+	                                             "stop: 0 #933, "
+	                                             "stop: 1 #822);"
 	        "}";
 }
 
@@ -149,7 +199,6 @@ void k9call::updateQuery()
 void k9call::nextContact() {
 	if(m_ActiveSet.size() == 0) {
 		ui.name->setText("");
-		ui.name->setIcon(QIcon());
 		ui.name->setEnabled(false);
 		return;
 	}
@@ -166,22 +215,35 @@ void k9call::nextContact() {
 	// Setup code for thumbnail
 	QContactThumbnail detail = contact.detail(QContactThumbnail::DefinitionName);
 	QImage thumbnail = detail.thumbnail().convertToFormat(QImage::Format_RGB32);
+	if(thumbnail.isNull()) {
+		// No thumbnail so just clear the pic
+		QGraphicsScene *scene = ui.pic->scene();
+		scene->clear();
+	}
+	else {
+		// Scale the image to fit (upscale until Nokia pushes the fix thorugh, same bug as below)
+		thumbnail = thumbnail.scaled(ui.pic->size(), Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation);
 
-	// Need to convert BGR to RGB (http://bugreports.qt.nokia.com/browse/QTMOBILITY-307)
-	{
-		int size = thumbnail.width() * thumbnail.height();
-		QRgb* data = reinterpret_cast<QRgb*>(const_cast<uchar*>(thumbnail.bits()));
-		for(int i = 0; i < size; i++) {
-			QRgb &abgr = data[i];
-			QRgb r = (abgr & 0x000000FF) << 16;
-			QRgb g =  abgr & 0xFF00FF00;
-			QRgb b = (abgr & 0x00FF0000) >> 16;
-			
-			abgr = r | g | b;
+		// Need to convert BGR to RGB (http://bugreports.qt.nokia.com/browse/QTMOBILITY-307)
+		{
+			int size = thumbnail.width() * thumbnail.height();
+			QRgb* data = reinterpret_cast<QRgb*>(const_cast<uchar*>(thumbnail.bits()));
+			for(int i = 0; i < size; i++) {
+				QRgb &abgr = data[i];
+				QRgb r = (abgr & 0x000000FF) << 16;
+				QRgb g =  abgr & 0xFF00FF00;
+				QRgb b = (abgr & 0x00FF0000) >> 16;
+				
+				abgr = r | g | b;
+			}
 		}
+
+		// Render Image
+		QPixmap pix = QPixmap::fromImage(thumbnail);
+		QGraphicsScene *scene = ui.pic->scene();
+		scene->clear();
+		scene->addPixmap(pix);
 	}
-	QPixmap pix = QPixmap::fromImage(thumbnail);
-	ui.name->setIcon(QIcon(pix));
 
     m_PhoneNumbers = contact.details<QContactPhoneNumber>();
 	m_PhoneNumbersItr = m_PhoneNumbers.constBegin();
