@@ -18,7 +18,6 @@ int main(int argc, char *argv[])
 	QGraphicsScene scene;
 	QGraphicsProxyWidget *proxy = scene.addWidget(&w);
 	QGraphicsView view(&scene);
-	QMaemo5HomescreenAdaptor adaptor(&view);
 
 	// Setup the Widget
 	proxy->setMaximumSize(400,600);
@@ -29,6 +28,11 @@ int main(int argc, char *argv[])
 	view.setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 	view.rotate(-90);
 
+	view.setAttribute(Qt::WA_TranslucentBackground);
+	view.setStyleSheet("background: transparent");
+
+	// Attach the adaptor
+	QMaemo5HomescreenAdaptor adaptor(&view);
 	adaptor.setSettingsAvailable(true);
 	QObject::connect(&adaptor, SIGNAL(settingsRequested()), &w, SLOT(openSettings()));
 
